==> haskell-quickcheck-unicode-1.0.1.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-6DEKMiPkZX37VqzWWP28i8
key:                  quickcheck-unicode-1.0.1.0-6DEKMiPkZX37VqzWWP28i8
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  f865ab3c083517925bdd3fe9eea0a774
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-8.10.2/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/quickcheck-unicode-1.0.1.0

hs-libraries:         HSquickcheck-unicode-1.0.1.0-6DEKMiPkZX37VqzWWP28i8
depends:              QuickCheck-2.14.1-64ImYjtdVDWOmMrx53wi base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-8NLYQaefWNa4PauUN2dch5
key:                  quickcheck-unicode-1.0.1.0-8NLYQaefWNa4PauUN2dch5
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  53f040c22374360e9e7e5e6f2af6c65c
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-8.10.2/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/quickcheck-unicode-1.0.1.0

hs-libraries:         HSquickcheck-unicode-1.0.1.0-8NLYQaefWNa4PauUN2dch5
depends:
    QuickCheck-2.14.2-FmEUKzgdJtTLjFqTjEvyPC base-4.14.1.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
